@@ -1,7 +1,7 @@
-import itertools
 import re
 import typing
 from collections import defaultdict
+from itertools import takewhile
 from operator import attrgetter
 
 from pkgcore import fetch
@@ -48,7 +48,7 @@ def get_python_eclass(pkg):
 
 
 def is_python_interpreter(pkg):
-    if pkg.key == "dev-lang/python":
+    if pkg.key in ("dev-lang/pypy", "dev-lang/python"):
         # ignore python:2.7 deps since they are being phased out from eclass
         # support
         return pkg.slot is None or not pkg.slot.startswith("2")
@@ -358,7 +358,7 @@ class PythonCheck(Check):
         uses_setuptools_scm = False
         pep517_value = None
 
-        for var_node, _ in bash.var_assign_query.captures(pkg.tree.root_node):
+        for var_node in bash.var_assign_query.captures(pkg.tree.root_node).get("assign", ()):
             var_name = pkg.node_str(var_node.child_by_field_name("name"))
 
             if var_name == "DISTUTILS_OPTIONAL":
@@ -376,7 +376,8 @@ class PythonCheck(Check):
         bdepends = frozenset(map(attrgetter("key"), iflatten_instance(pkg.bdepend, atom)))
 
         if pep517_value is None:
-            yield DistutilsNonPEP517Build(pkg=pkg)
+            if "dev-python/gpep517" not in bdepends:
+                yield DistutilsNonPEP517Build(pkg=pkg)
         elif has_distutils_optional and not has_distutils_deps and pep517_value != "no":
             # We always need BDEPEND for these if != no.
             # We are looking for USE-conditional on appropriate target
@@ -406,7 +407,7 @@ class PythonCheck(Check):
         for var_node in pkg.global_query(bash.var_assign_query):
             name = pkg.node_str(var_node.child_by_field_name("name"))
             if name in {"DEPEND", "BDEPEND"}:
-                for call_node, _ in bash.cmd_query.captures(var_node):
+                for call_node in bash.cmd_query.captures(var_node).get("call", ()):
                     call_name = pkg.node_str(call_node.child_by_field_name("name"))
                     if call_name == any_dep_func and len(call_node.children) > 1:
                         check_deps[name].update(
@@ -456,7 +457,7 @@ class PythonCheck(Check):
     def check_python_check_deps(self, pkg, func_node, python_check_deps, any_dep_func):
         has_version_checked_deps = defaultdict(set)
         has_version_lines = set()
-        for node, _ in bash.cmd_query.captures(func_node):
+        for node in bash.cmd_query.captures(func_node).get("call", ()):
             call_name = pkg.node_str(node.child_by_field_name("name"))
             if call_name == "has_version":
                 lineno, _ = node.start_point
@@ -547,7 +548,7 @@ class PythonCheck(Check):
 
         any_dep_func = self.eclass_any_dep_func[eclass]
         python_check_deps = self.build_python_gen_any_dep_calls(pkg, any_dep_func)
-        for func_node, _ in bash.func_query.captures(pkg.tree.root_node):
+        for func_node in bash.func_query.captures(pkg.tree.root_node).get("func", ()):
             func_name = pkg.node_str(func_node.child_by_field_name("name"))
             if func_name == "python_check_deps":
                 yield from self.check_python_check_deps(
@@ -578,6 +579,18 @@ class PythonCompatCheck(Check):
 
     known_results = frozenset([PythonCompatUpdate])
 
+    whitelist_backports = frozenset(
+        {
+            "dev-python/backports-tarfile",
+            "dev-python/exceptiongroup",
+            "dev-python/importlib-metadata",
+            "dev-python/taskgroup",
+            "dev-python/typing-extensions",
+            "dev-python/unittest-or-fail",
+            "dev-python/zipp",
+        }
+    )
+
     def __init__(self, *args):
         super().__init__(*args)
         repo = self.options.target_repo
@@ -620,7 +633,7 @@ class PythonCompatCheck(Check):
             p
             for attr in (x.lower() for x in attrs)
             for p in iflatten_instance(getattr(pkg, attr), atom)
-            if not p.blocks
+            if not p.blocks and p.key not in self.whitelist_backports
         }
 
     def feed(self, pkg):
@@ -651,9 +664,7 @@ class PythonCompatCheck(Check):
             return
 
         # determine python impls to target
-        targets = set(
-            itertools.takewhile(lambda x: x != latest_target, reversed(available_targets))
-        )
+        targets = set(takewhile(lambda x: x != latest_target, reversed(available_targets)))
 
         if targets:
             try:
@@ -935,5 +946,5 @@ class PythonPackageNameCheck(Check):
             return PROJECT_SYMBOL_NORMALIZE_RE.sub("-", project).lower()
 
         pypi_name = pypi_remotes[0].name
-        if normalize(pkg.package) != normalize(pypi_name):
-            yield PythonMismatchedPackageName(pypi_name.replace(".", "-"), pkg=pkg)
+        if pkg.package != normalize(pypi_name):
+            yield PythonMismatchedPackageName(normalize(pypi_name), pkg=pkg)
